@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this library; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2008,2011,2012,2014,2017 Øyvind Kolås <pippin@gimp.org>
  *           2013 Daniel Sabo
@@ -25,13 +25,12 @@
 #include <glib-object.h>
 #include <glib/gprintf.h>
 
-#include "gegl.h"
+#include "gegl-buffer.h"
 #include "gegl-buffer-types.h"
 #include "gegl-buffer-iterator.h"
 #include "gegl-buffer-iterator-private.h"
 #include "gegl-buffer-private.h"
-#include "gegl-buffer-cl-cache.h"
-#include "gegl-config.h"
+#include "gegl-rectangle.h"
 
 typedef enum {
   GeglIteratorState_Start,
@@ -79,8 +78,6 @@ struct _GeglBufferIteratorPriv
   SubIterState      sub_iter[GEGL_BUFFER_MAX_ITERATORS];
 };
 
-static gboolean threaded = TRUE;
-
 static inline GeglBufferIterator *
 _gegl_buffer_iterator_empty_new (void)
 {
@@ -90,8 +87,6 @@ _gegl_buffer_iterator_empty_new (void)
   iter->priv->num_buffers = 0;
   iter->priv->state       = GeglIteratorState_Start;
 
-  threaded = gegl_config_threads () > 1;
-
   return iter;
 }
 
@@ -194,6 +189,8 @@ release_tile (GeglBufferIterator *iter,
     {
       if (sub->access_mode & GEGL_ACCESS_WRITE)
         gegl_tile_unlock_no_void (sub->current_tile);
+      else
+        gegl_tile_read_unlock (sub->current_tile);
       gegl_tile_unref (sub->current_tile);
 
       sub->current_tile = NULL;
@@ -348,6 +345,8 @@ get_tile (GeglBufferIterator *iter,
 
       if (sub->access_mode & GEGL_ACCESS_WRITE)
         gegl_tile_lock (sub->current_tile);
+      else
+        gegl_tile_read_lock (sub->current_tile);
 
       sub->real_roi.x = (tile_x * tile_width)  - shift_x;
       sub->real_roi.y = (tile_y * tile_height) - shift_y;
@@ -473,6 +472,8 @@ prepare_iteration (GeglBufferIterator *iter)
 
               if (sub->access_mode & GEGL_ACCESS_WRITE)
                 gegl_tile_lock (sub->linear_tile);
+              else
+                gegl_tile_read_lock (sub->linear_tile);
             }
           else
             sub->access_mode |= GEGL_ITERATOR_INCOMPATIBLE;
@@ -546,6 +547,8 @@ _gegl_buffer_iterator_stop (GeglBufferIterator *iter)
             {
               if (sub->access_mode & GEGL_ACCESS_WRITE)
                 gegl_tile_unlock_no_void (sub->linear_tile);
+              else
+                gegl_tile_read_unlock (sub->linear_tile);
               gegl_tile_unref (sub->linear_tile);
             }
 
@@ -658,11 +661,11 @@ gegl_buffer_iterator_next (GeglBufferIterator *iter)
           && FALSE) /* XXX: conditions are not strict enough, GIMPs TIFF
                        plug-in fails; but GEGLs buffer test suite passes */
       {
-        if (gegl_cl_is_accelerated ())
+        if (gegl_buffer_ext_flush)
           for (index = 0; index < priv->num_buffers; index++)
             {
               SubIterState *sub = &priv->sub_iter[index];
-              gegl_buffer_cl_cache_flush (sub->buffer, &sub->full_rect);
+              gegl_buffer_ext_flush (sub->buffer, &sub->full_rect);
             }
         linear_shortcut (iter);
         return TRUE;
@@ -670,11 +673,11 @@ gegl_buffer_iterator_next (GeglBufferIterator *iter)
 
       prepare_iteration (iter);
 
-      if (gegl_cl_is_accelerated ())
+      if (gegl_buffer_ext_flush)
         for (index = 0; index < priv->num_buffers; index++)
           {
             SubIterState *sub = &priv->sub_iter[index];
-            gegl_buffer_cl_cache_flush (sub->buffer, &sub->full_rect);
+            gegl_buffer_ext_flush (sub->buffer, &sub->full_rect);
           }
 
       initialize_rects (iter);
