@@ -5,9 +5,10 @@
 #include <glib-object.h>
 #include <glib/gprintf.h>
 
-#include "gegl.h"
-#include "gegl-types-internal.h"
+#include "gegl-buffer.h"
+#include "gegl-buffer-formats.h"
 #include "gegl-buffer-types.h"
+#include "gegl-rectangle.h"
 #include "gegl-buffer-private.h"
 #include "gegl-tile-storage.h"
 #include "gegl-tile-handler-cache.h"
