@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, see <http://www.gnu.org/licenses/>.
+ * License along with this library; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2006, 2007 Øyvind Kolås <pippin@gimp.org>
  */
@@ -26,7 +26,7 @@
 #include <fcntl.h>
 #include <unistd.h>
 
-#include "gegl.h"
+#include "gegl-buffer.h"
 #include "gegl-buffer-private.h"
 #include "gegl-buffer-index.h"
 #include "gegl-debug.h"
