@@ -36,16 +36,17 @@
 #include <glib-object.h>
 #include <glib/gstdio.h>
 
-#include "gegl-buffer-types.h"
-#include "gegl-buffer.h"
-#include "gegl-buffer-private.h"
 #include "gegl-debug.h"
+#include "gegl-buffer.h"
+#include "gegl-buffer-types.h"
+#include "gegl-buffer-config.h"
+#include "gegl-buffer-private.h"
+#include "gegl-rectangle.h"
 #include "gegl-tile-storage.h"
 #include "gegl-tile-backend-file.h"
 #include "gegl-tile-backend-swap.h"
 #include "gegl-tile-backend-ram.h"
-#include "gegl-buffer-cl-cache.h"
-#include "gegl-config.h" /* XXX: include of file outside buffer dir */
+#include "gegl-buffer-formats.h"
 
 #ifdef GEGL_ENABLE_DEBUG
 #define DEBUG_ALLOCATIONS (gegl_debug_flags & GEGL_DEBUG_BUFFER_ALLOC)
@@ -279,6 +280,8 @@ static GList         *allocated_buffers_list = NULL;
 static volatile gint  allocated_buffers      = 0;
 static volatile gint  de_allocated_buffers   = 0;
 
+
+
 /* this should only be possible if this buffer matches all the buffers down to
  * storage, all of those parent buffers would change size as well, no tiles
  * would be voided as a result of changing the extent.
@@ -326,8 +329,7 @@ gegl_buffer_leaks (void)
     {
       GList *leaked_buffer = NULL;
 
-      if (gegl_config_threads()>1)
-        g_mutex_lock (&allocated_buffers_mutex);
+      g_mutex_lock (&allocated_buffers_mutex);
 
       for (leaked_buffer = allocated_buffers_list;
            leaked_buffer != NULL;
@@ -346,8 +348,7 @@ gegl_buffer_leaks (void)
       g_list_free (allocated_buffers_list);
       allocated_buffers_list = NULL;
 
-      if (gegl_config_threads()>1)
-        g_mutex_unlock (&allocated_buffers_mutex);
+      g_mutex_unlock (&allocated_buffers_mutex);
     }
 #endif
 
@@ -372,8 +373,8 @@ gegl_buffer_dispose (GObject *object)
   GeglBuffer  *buffer  = GEGL_BUFFER (object);
   GeglTileHandler *handler = GEGL_TILE_HANDLER (object);
 
-  if (gegl_cl_is_accelerated ())
-    gegl_buffer_cl_cache_invalidate (GEGL_BUFFER (object), NULL);
+  if (gegl_buffer_ext_flush)
+    gegl_buffer_ext_flush (buffer, NULL);
 
   if (GEGL_IS_TILE_STORAGE (handler->source))
     {
@@ -400,11 +401,9 @@ gegl_buffer_finalize (GObject *object)
 #ifdef GEGL_ENABLE_DEBUG
   if (DEBUG_ALLOCATIONS)
     {
-      if (gegl_config_threads()>1)
-        g_mutex_lock (&allocated_buffers_mutex);
+      g_mutex_lock (&allocated_buffers_mutex);
       allocated_buffers_list = g_list_remove (allocated_buffers_list, object);
-      if (gegl_config_threads()>1)
-        g_mutex_unlock (&allocated_buffers_mutex);
+      g_mutex_unlock (&allocated_buffers_mutex);
       g_free (GEGL_BUFFER (object)->alloc_stack_trace);
     }
 #endif
@@ -525,7 +524,7 @@ gegl_buffer_constructor (GType                  type,
           if (!buffer->format)
             {
               g_warning ("Buffer constructed without format, assuming RGBA float");
-              buffer->format = gegl_babl_rgba_linear_float ();
+              buffer->format = babl_format ("RGBA float");
             }
 
           /* make a new backend & storage */
@@ -533,7 +532,7 @@ gegl_buffer_constructor (GType                  type,
           if (buffer->path)
             maybe_path = buffer->path;
           else
-            maybe_path = gegl_config ()->swap;
+            maybe_path = gegl_buffer_config ()->swap;
 
           if (maybe_path)
             use_ram = g_ascii_strcasecmp (maybe_path, "ram") == 0;
@@ -849,13 +848,13 @@ gegl_buffer_class_init (GeglBufferClass *class)
 
   g_object_class_install_property (gobject_class, PROP_TILE_HEIGHT,
                                    g_param_spec_int ("tile-height", "tile-height", "height of a tile",
-                                                     -1, G_MAXINT, gegl_config()->tile_height,
+                                                     -1, G_MAXINT, gegl_buffer_config()->tile_height,
                                                      G_PARAM_READWRITE |
                                                      G_PARAM_CONSTRUCT_ONLY));
 
   g_object_class_install_property (gobject_class, PROP_TILE_WIDTH,
                                    g_param_spec_int ("tile-width", "tile-width", "width of a tile",
-                                                     -1, G_MAXINT, gegl_config()->tile_width,
+                                                     -1, G_MAXINT, gegl_buffer_config()->tile_width,
                                                      G_PARAM_READWRITE |
                                                      G_PARAM_CONSTRUCT_ONLY));
 
@@ -924,11 +923,9 @@ gegl_buffer_init (GeglBuffer *buffer)
   if (DEBUG_ALLOCATIONS)
     {
       gegl_buffer_set_alloc_stack (buffer);
-      if (gegl_config_threads()>1)
-        g_mutex_lock (&allocated_buffers_mutex);
+      g_mutex_lock (&allocated_buffers_mutex);
       allocated_buffers_list = g_list_prepend (allocated_buffers_list, buffer);
-      if (gegl_config_threads()>1)
-        g_mutex_unlock (&allocated_buffers_mutex);
+      g_mutex_unlock (&allocated_buffers_mutex);
     }
 #endif
 }
@@ -1122,18 +1119,14 @@ gegl_buffer_try_lock (GeglBuffer *buffer)
   {
     GeglTileBackend *backend = gegl_buffer_backend (buffer);
 
-    gboolean threaded = gegl_config_threads ()>1;
-
-    if (threaded)
-      g_rec_mutex_lock (&buffer->tile_storage->mutex);
+    g_rec_mutex_lock (&buffer->tile_storage->mutex);
     if (buffer->lock_count > 0)
       buffer->lock_count++;
     else if (gegl_tile_backend_file_try_lock (GEGL_TILE_BACKEND_FILE (backend)))
       buffer->lock_count++;
     else
       ret = FALSE;
-    if (threaded)
-      g_rec_mutex_unlock (&buffer->tile_storage->mutex);
+    g_rec_mutex_unlock (&buffer->tile_storage->mutex);
   }
 
   return ret;
@@ -1158,11 +1151,9 @@ gegl_buffer_unlock (GeglBuffer *buffer)
 
   if (gegl_buffer_is_shared (buffer))
   {
-    gboolean threaded = gegl_config_threads ()>1;
     GeglTileBackend *backend = gegl_buffer_backend (buffer);
 
-    if (threaded)
-      g_rec_mutex_lock (&buffer->tile_storage->mutex);
+    g_rec_mutex_lock (&buffer->tile_storage->mutex);
 
     buffer->lock_count--;
     g_assert (buffer->lock_count >= 0);
@@ -1170,8 +1161,7 @@ gegl_buffer_unlock (GeglBuffer *buffer)
     if (buffer->lock_count == 0)
       ret = gegl_tile_backend_file_unlock (GEGL_TILE_BACKEND_FILE (backend));
 
-    if (threaded)
-      g_rec_mutex_unlock (&buffer->tile_storage->mutex);
+    g_rec_mutex_unlock (&buffer->tile_storage->mutex);
   }
 
   return ret;
@@ -1214,24 +1204,21 @@ gegl_buffer_get_tile (GeglBuffer *buffer,
   GeglTile *tile;
 
   g_assert (source);
-
-  if (gegl_config_threads () > 1)
   {
-    GeglTileStorage *tile_storage = buffer->tile_storage;
-    g_assert (tile_storage);
+  GeglTileStorage *tile_storage = buffer->tile_storage;
+  g_assert (tile_storage);
 
-    g_rec_mutex_lock (&tile_storage->mutex);
+  g_rec_mutex_lock (&tile_storage->mutex);
 
-    tile = gegl_tile_source_command (source, GEGL_TILE_GET,
-                                     x, y, z, NULL);
+  tile = gegl_tile_source_command (source, GEGL_TILE_GET,
+                                   x, y, z, NULL);
 
-    g_rec_mutex_unlock (&tile_storage->mutex);
-  }
-  else
-  {
-    return gegl_tile_source_command (source, GEGL_TILE_GET,
-                                     x, y, z, NULL);
+  g_rec_mutex_unlock (&tile_storage->mutex);
   }
 
   return tile;
 }
+
+void (*gegl_tile_handler_cache_ext_flush) (void *cache, const GeglRectangle *rect)=NULL;
+void (*gegl_buffer_ext_flush) (GeglBuffer *buffer, const GeglRectangle *rect)=NULL;
+void (*gegl_buffer_ext_invalidate) (GeglBuffer *buffer, const GeglRectangle *rect)=NULL;
