@@ -24,19 +24,17 @@
 #include <string.h>
 #include <math.h>
 
-#include "gegl.h"
-#include "gegl-buffer-types.h"
 #include "gegl-buffer.h"
+#include "gegl-buffer-types.h"
 #include "gegl-buffer-private.h"
-#include "gegl-buffer-cl-cache.h"
 
 #include "gegl-sampler-nearest.h"
 #include "gegl-sampler-linear.h"
 #include "gegl-sampler-cubic.h"
 #include "gegl-sampler-nohalo.h"
 #include "gegl-sampler-lohalo.h"
+#include "gegl-buffer-formats.h"
 
-#include "gegl-config.h"
 
 enum
 {
@@ -149,12 +147,12 @@ constructed (GObject *self)
 }
 
 void
-gegl_sampler_get (GeglSampler     *self,
-                  gdouble          x,
-                  gdouble          y,
-                  GeglMatrix2     *scale,
-                  void            *output,
-                  GeglAbyssPolicy  repeat_mode)
+gegl_sampler_get (GeglSampler       *self,
+                  gdouble            x,
+                  gdouble            y,
+                  GeglBufferMatrix2 *scale,
+                  void              *output,
+                  GeglAbyssPolicy    repeat_mode)
 {
   if (G_UNLIKELY(!isfinite (x)))
     x = 0.0;
@@ -169,10 +167,10 @@ gegl_sampler_get (GeglSampler     *self,
     return;
   }
 
-  if (gegl_cl_is_accelerated ())
+  if (gegl_buffer_ext_flush)
     {
       GeglRectangle rect={x,y,1,1};
-      gegl_buffer_cl_cache_flush (self->buffer, &rect);
+      gegl_buffer_ext_flush (self->buffer, &rect);
     }
   self->get (self, x, y, scale, output, repeat_mode);
 }
@@ -268,10 +266,10 @@ gegl_sampler_get_from_mipmap (GeglSampler    *sampler,
   const gint maximum_width  = GEGL_SAMPLER_MAXIMUM_WIDTH;
   const gint maximum_height = GEGL_SAMPLER_MAXIMUM_HEIGHT;
 
-  if (gegl_cl_is_accelerated ())
+  if (gegl_buffer_ext_flush)
     {
       GeglRectangle rect = {x, y, 1, 1};
-      gegl_buffer_cl_cache_flush (sampler->buffer, &rect);
+      gegl_buffer_ext_flush (sampler->buffer, &rect);
     }
 
   g_assert (level_no >= 0 && level_no < GEGL_SAMPLER_MIPMAP_LEVELS);
@@ -417,15 +415,15 @@ gegl_sampler_gtype_from_enum (GeglSamplerType sampler_type)
 }
 
 static inline void
-_gegl_buffer_sample_at_level (GeglBuffer       *buffer,
-                              gdouble           x,
-                              gdouble           y,
-                              GeglMatrix2      *scale,
-                              gpointer          dest,
-                              const Babl       *format,
-                              gint              level,
-                              GeglSamplerType   sampler_type,
-                              GeglAbyssPolicy   repeat_mode)
+_gegl_buffer_sample_at_level (GeglBuffer        *buffer,
+                              gdouble            x,
+                              gdouble            y,
+                              GeglBufferMatrix2 *scale,
+                              gpointer           dest,
+                              const Babl        *format,
+                              gint               level,
+                              GeglSamplerType    sampler_type,
+                              GeglAbyssPolicy    repeat_mode)
 {
   GeglSampler *sampler;
 
@@ -451,15 +449,15 @@ _gegl_buffer_sample_at_level (GeglBuffer       *buffer,
 }
 
 void
-gegl_buffer_sample_at_level (GeglBuffer       *buffer,
-                             gdouble           x,
-                             gdouble           y,
-                             GeglMatrix2      *scale,
-                             gpointer          dest,
-                             const Babl       *format,
-                             gint              level,
-                             GeglSamplerType   sampler_type,
-                             GeglAbyssPolicy   repeat_mode)
+gegl_buffer_sample_at_level (GeglBuffer        *buffer,
+                             gdouble            x,
+                             gdouble            y,
+                             GeglBufferMatrix2 *scale,
+                             gpointer           dest,
+                             const Babl        *format,
+                             gint               level,
+                             GeglSamplerType    sampler_type,
+                             GeglAbyssPolicy    repeat_mode)
 {
   _gegl_buffer_sample_at_level (buffer, x, y, scale, dest,
                                 format, level, sampler_type, repeat_mode);
@@ -467,14 +465,14 @@ gegl_buffer_sample_at_level (GeglBuffer       *buffer,
 
 
 void
-gegl_buffer_sample (GeglBuffer       *buffer,
-                    gdouble           x,
-                    gdouble           y,
-                    GeglMatrix2      *scale,
-                    gpointer          dest,
-                    const Babl       *format,
-                    GeglSamplerType   sampler_type,
-                    GeglAbyssPolicy   repeat_mode)
+gegl_buffer_sample (GeglBuffer        *buffer,
+                    gdouble            x,
+                    gdouble            y,
+                    GeglBufferMatrix2 *scale,
+                    gpointer           dest,
+                    const Babl        *format,
+                    GeglSamplerType    sampler_type,
+                    GeglAbyssPolicy    repeat_mode)
 {
   _gegl_buffer_sample_at_level (buffer, x, y, scale, dest, format, 0, sampler_type, repeat_mode);
 }
@@ -554,8 +552,8 @@ GeglSamplerGetFun gegl_sampler_get_fun (GeglSampler *sampler)
   /* this flushes the buffer in preparation for the use of the sampler,
    * thus one can consider the handed out sampler function only temporarily
    * available*/
-  if (gegl_cl_is_accelerated ())
-    gegl_buffer_cl_cache_flush (sampler->buffer, NULL);
+  if (gegl_buffer_ext_flush)
+    gegl_buffer_ext_flush (sampler->buffer, NULL);
   return sampler->get;
 }
 
