@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2006, 2007 Øyvind Kolås <pippin@gimp.org>
  */
@@ -103,9 +103,14 @@ GeglTileSource *gegl_tile_backend_peek_storage  (GeglTileBackend *tile_backend);
  * backend with the width/height information when constructing proxy
  * GeglBuffers to interact with other systems
  */
-void  gegl_tile_backend_set_extent    (GeglTileBackend *tile_backend,
-                                       GeglRectangle   *rectangle);
+void  gegl_tile_backend_set_extent    (GeglTileBackend     *tile_backend,
+                                       const GeglRectangle *rectangle);
 
+
+/**
+ * gegl_tile_backend_get_extent: (skip)
+ * @tile_backend: a #GeglTileBackend
+ */
 GeglRectangle gegl_tile_backend_get_extent (GeglTileBackend *tile_backend);
 
 /**
@@ -121,6 +126,27 @@ void gegl_tile_backend_set_flush_on_destroy (GeglTileBackend *tile_backend,
 
 gboolean gegl_tile_backend_get_flush_on_destroy (GeglTileBackend *tile_backend);
 
+/**
+ * gegl_tile_backend_command:
+ * @backend: a #GeglTileBackend
+ * @command: the tile command
+ * @x: x coordinate
+ * @y: y coordinate
+ * @z: tile zoom level
+ * @data: user data
+ *
+ * The default tile-backend command handler.  Tile backends should forward
+ * commands they don't handle themselves to this function.
+ *
+ * Returns: Command result.
+ */
+gpointer gegl_tile_backend_command (GeglTileBackend *backend,
+                                    GeglTileCommand  command,
+                                    gint             x,
+                                    gint             y,
+                                    gint             z,
+                                    gpointer         data);
+
 GType gegl_tile_backend_get_type (void) G_GNUC_CONST;
 
 /**
