@@ -21,15 +21,14 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include "gegl-config.h"
+#include "gegl-buffer-config.h"
 #include "gegl-buffer.h"
 #include "gegl-buffer-private.h"
 #include "gegl-tile.h"
 #include "gegl-tile-handler-cache.h"
+#include "gegl-tile-storage.h"
 #include "gegl-debug.h"
 
-#include "gegl-buffer-cl-cache.h"
-
 /*
 #define GEGL_DEBUG_CACHE_HITS
 */
@@ -51,39 +50,44 @@ typedef struct CacheItem
         ((CacheItem *) ((guchar *) l - G_STRUCT_OFFSET (CacheItem, link)))
 
 
-static gboolean   gegl_tile_handler_cache_equalfunc  (gconstpointer         a,
-                                                      gconstpointer         b);
-static guint      gegl_tile_handler_cache_hashfunc   (gconstpointer         key);
-static void       gegl_tile_handler_cache_dispose    (GObject              *object);
-static gboolean   gegl_tile_handler_cache_wash       (GeglTileHandlerCache *cache);
-static gpointer   gegl_tile_handler_cache_command    (GeglTileSource       *tile_store,
-                                                      GeglTileCommand       command,
-                                                      gint                  x,
-                                                      gint                  y,
-                                                      gint                  z,
-                                                      gpointer              data);
-static GeglTile * gegl_tile_handler_cache_get_tile   (GeglTileHandlerCache *cache,
-                                                      gint                  x,
-                                                      gint                  y,
-                                                      gint                  z);
-static gboolean   gegl_tile_handler_cache_has_tile   (GeglTileHandlerCache *cache,
-                                                      gint                  x,
-                                                      gint                  y,
-                                                      gint                  z);
-void              gegl_tile_handler_cache_insert     (GeglTileHandlerCache *cache,
-                                                      GeglTile             *tile,
-                                                      gint                  x,
-                                                      gint                  y,
-                                                      gint                  z);
-static void       gegl_tile_handler_cache_void       (GeglTileHandlerCache *cache,
-                                                      gint                  x,
-                                                      gint                  y,
-                                                      gint                  z,
-                                                      guint64               damage);
-static void       gegl_tile_handler_cache_invalidate (GeglTileHandlerCache *cache,
-                                                      gint                  x,
-                                                      gint                  y,
-                                                      gint                  z);
+static gboolean   gegl_tile_handler_cache_equalfunc  (gconstpointer             a,
+                                                      gconstpointer             b);
+static guint      gegl_tile_handler_cache_hashfunc   (gconstpointer             key);
+static void       gegl_tile_handler_cache_dispose    (GObject                  *object);
+static gboolean   gegl_tile_handler_cache_wash       (GeglTileHandlerCache     *cache);
+static gpointer   gegl_tile_handler_cache_command    (GeglTileSource           *tile_store,
+                                                      GeglTileCommand           command,
+                                                      gint                      x,
+                                                      gint                      y,
+                                                      gint                      z,
+                                                      gpointer                  data);
+static GeglTile * gegl_tile_handler_cache_get_tile   (GeglTileHandlerCache     *cache,
+                                                      gint                      x,
+                                                      gint                      y,
+                                                      gint                      z);
+static gboolean   gegl_tile_handler_cache_has_tile   (GeglTileHandlerCache     *cache,
+                                                      gint                      x,
+                                                      gint                      y,
+                                                      gint                      z);
+void              gegl_tile_handler_cache_insert     (GeglTileHandlerCache     *cache,
+                                                      GeglTile                 *tile,
+                                                      gint                      x,
+                                                      gint                      y,
+                                                      gint                      z);
+static void       gegl_tile_handler_cache_void       (GeglTileHandlerCache     *cache,
+                                                      gint                      x,
+                                                      gint                      y,
+                                                      gint                      z,
+                                                      guint64                   damage);
+static void       gegl_tile_handler_cache_invalidate (GeglTileHandlerCache     *cache,
+                                                      gint                      x,
+                                                      gint                      y,
+                                                      gint                      z);
+static gboolean   gegl_tile_handler_cache_copy       (GeglTileHandlerCache     *cache,
+                                                      gint                      x,
+                                                      gint                      y,
+                                                      gint                      z,
+                                                      const GeglTileCopyParams *params);
 
 
 static GMutex             mutex                 = { 0, };
@@ -188,8 +192,8 @@ gegl_tile_handler_cache_get_tile_command (GeglTileSource *tile_store,
   GeglTileSource       *source   = ((GeglTileHandler*) (tile_store))->source;
   GeglTile             *tile     = NULL;
 
-  if (G_UNLIKELY (gegl_cl_is_accelerated ()))
-    gegl_buffer_cl_cache_flush2 (cache, NULL);
+  if (gegl_tile_handler_cache_ext_flush)
+    gegl_tile_handler_cache_ext_flush (cache, NULL);
 
   tile = gegl_tile_handler_cache_get_tile (cache, x, y, z);
   if (tile)
@@ -228,8 +232,8 @@ gegl_tile_handler_cache_command (GeglTileSource  *tile_store,
         {
           GList *link;
 
-          if (gegl_cl_is_accelerated ())
-            gegl_buffer_cl_cache_flush2 (cache, NULL);
+          if (gegl_tile_handler_cache_ext_flush)
+            gegl_tile_handler_cache_ext_flush (cache, NULL);
 
           for (link = g_queue_peek_head_link (&cache->queue);
                link;
@@ -276,6 +280,12 @@ gegl_tile_handler_cache_command (GeglTileSource  *tile_store,
       case GEGL_TILE_REINIT:
         gegl_tile_handler_cache_reinit (cache);
         break;
+      case GEGL_TILE_COPY:
+        /* we potentially chain up in gegl_tile_handler_cache_copy(), because
+         * its logic is interleaved with that of the backend.
+         */
+        return GINT_TO_POINTER (gegl_tile_handler_cache_copy (cache,
+                                                              x, y, z, data));
       default:
         break;
     }
@@ -396,8 +406,7 @@ gegl_tile_handler_cache_wash (GeglTileHandlerCache *cache)
       if (cache == NULL)
         break;
 
-      if (gegl_config_threads()>1 &&
-          ! g_rec_mutex_trylock (&cache->tile_storage->mutex))
+      if (! g_rec_mutex_trylock (&cache->tile_storage->mutex))
         {
           continue;
         }
@@ -422,8 +431,7 @@ gegl_tile_handler_cache_wash (GeglTileHandlerCache *cache)
           size += tile->size;
         }
 
-      if (gegl_config_threads()>1)
-        g_rec_mutex_unlock (&cache->tile_storage->mutex);
+      g_rec_mutex_unlock (&cache->tile_storage->mutex);
     }
 
   g_mutex_unlock (&mutex);
@@ -513,20 +521,20 @@ gegl_tile_handler_cache_trim (GeglTileHandlerCache *cache)
   g_mutex_lock (&mutex);
 
   while ((guintptr) g_atomic_pointer_get (&cache_total) >
-         gegl_config ()->tile_cache_size)
+         gegl_buffer_config ()->tile_cache_size)
     {
       CacheItem *last_writable;
       GeglTile  *tile;
       GList     *prev_link;
 
 #ifdef GEGL_DEBUG_CACHE_HITS
-      GEGL_NOTE(GEGL_DEBUG_CACHE, "cache_total:"G_GUINT64_FORMAT" > cache_size:"G_GUINT64_FORMAT, cache_total, gegl_config()->tile_cache_size);
+      GEGL_NOTE(GEGL_DEBUG_CACHE, "cache_total:"G_GUINT64_FORMAT" > cache_size:"G_GUINT64_FORMAT, cache_total, gegl_buffer_config()->tile_cache_size);
       GEGL_NOTE(GEGL_DEBUG_CACHE, "%f%% hit:%i miss:%i  %i]", cache_hits*100.0/(cache_hits+cache_misses), cache_hits, cache_misses, g_queue_get_length (&cache_queue));
 #endif
 
       if (! link)
         {
-          if (cache && gegl_config_threads()>1)
+          if (cache)
             g_rec_mutex_unlock (&cache->tile_storage->mutex);
 
           do
@@ -542,7 +550,6 @@ gegl_tile_handler_cache_trim (GeglTileHandlerCache *cache)
                   * thread.  try locking the cache's storage mutex here, and
                   * skip the cache if it fails.
                   */
-                 gegl_config_threads()>1 &&
                  ! g_rec_mutex_trylock (&cache->tile_storage->mutex));
 
           if (! cache)
@@ -595,7 +602,7 @@ gegl_tile_handler_cache_trim (GeglTileHandlerCache *cache)
       link = prev_link;
     }
 
-  if (cache && gegl_config_threads()>1)
+  if (cache)
     g_rec_mutex_unlock (&cache->tile_storage->mutex);
 
   g_mutex_unlock (&mutex);
@@ -633,6 +640,110 @@ gegl_tile_handler_cache_invalidate (GeglTileHandlerCache *cache,
     }
 }
 
+static gboolean
+gegl_tile_handler_cache_copy (GeglTileHandlerCache     *cache,
+                              gint                      x,
+                              gint                      y,
+                              gint                      z,
+                              const GeglTileCopyParams *params)
+{
+  GeglTile *tile;
+  GeglTile *dst_tile = NULL;
+  gboolean  success  = FALSE;
+
+  if (gegl_tile_handler_cache_ext_flush)
+    gegl_tile_handler_cache_ext_flush (cache, NULL);
+
+  tile = gegl_tile_handler_cache_get_tile (cache, x, y, z);
+
+  /* if the tile is not fully valid, bail, so that the copy happens using a
+   * TILE_GET commands, validating the tile in the process.
+   */
+  if (tile && tile->damage)
+    {
+      gegl_tile_unref (tile);
+
+      return FALSE;
+    }
+
+  /* otherwise, if we have the tile and it's valid, copy it directly to the
+   * destination first, so that the copied tile will already be present in the
+   * destination cache.
+   */
+  if (tile)
+    {
+      GeglTileHandler *dst_handler;
+
+      if (params->dst_buffer)
+        dst_handler = GEGL_TILE_HANDLER (params->dst_buffer->tile_storage);
+      else
+        dst_handler = GEGL_TILE_HANDLER (cache);
+
+      dst_tile = gegl_tile_handler_dup_tile (dst_handler,
+                                             tile,
+                                             params->dst_x,
+                                             params->dst_y,
+                                             params->dst_z);
+
+      success = TRUE;
+    }
+
+  /* then, if we don't have the tile, or if the tile is stored, iow, if the
+   * tile might exist in the backend in an up-to-date state ...
+   */
+  if (! tile || gegl_tile_is_stored (tile))
+    {
+      /* ... try letting the backend copy the tile, so that the copied tile
+       * will already be stored in the destination backend.
+       */
+      if (gegl_tile_handler_source_command (GEGL_TILE_HANDLER (cache),
+                                            GEGL_TILE_COPY, x, y, z,
+                                            (gpointer) params))
+        {
+          /* if the backend copied the tile, we can either mark the copied tile
+           * as stored, or, if we didn't have the tile, void any existing tile
+           * in the destination cache.
+           */
+
+          if (dst_tile)
+            {
+              gegl_tile_mark_as_stored (dst_tile);
+            }
+          else
+            {
+              GeglTileHandlerCache *dst_cache;
+
+              if (params->dst_buffer)
+                dst_cache = params->dst_buffer->tile_storage->cache;
+              else
+                dst_cache = cache;
+
+              if (dst_cache)
+                {
+                  gegl_tile_handler_cache_void (dst_cache,
+                                                params->dst_x,
+                                                params->dst_y,
+                                                params->dst_z,
+                                                ~(guint64) 0);
+                }
+            }
+
+          success = TRUE;
+        }
+    }
+
+  if (dst_tile)
+    gegl_tile_unref (dst_tile);
+
+  if (tile)
+    gegl_tile_unref (tile);
+
+  /* the copy is considered successful if either we or the backend (or both)
+   * copied the tile.
+   */
+  return success;
+}
+
 
 static void
 gegl_tile_handler_cache_void (GeglTileHandlerCache *cache,
@@ -722,7 +833,7 @@ gegl_tile_handler_cache_tile_uncloned (GeglTileHandlerCache *cache,
   total = (guintptr) g_atomic_pointer_add (&cache_total, tile->size) +
           tile->size;
 
-  if (total > gegl_config ()->tile_cache_size)
+  if (total > gegl_buffer_config ()->tile_cache_size)
     gegl_tile_handler_cache_trim (cache);
 
   cache_total_max = MAX (cache_total_max, total);
@@ -842,9 +953,9 @@ gegl_tile_handler_cache_equalfunc (gconstpointer a,
 }
 
 static void
-gegl_config_tile_cache_size_notify (GObject    *gobject,
-                                    GParamSpec *pspec,
-                                    gpointer    user_data)
+gegl_buffer_config_tile_cache_size_notify (GObject    *gobject,
+                                           GParamSpec *pspec,
+                                           gpointer    user_data)
 {
   gegl_tile_handler_cache_trim (NULL);
 }
@@ -852,15 +963,15 @@ gegl_config_tile_cache_size_notify (GObject    *gobject,
 void
 gegl_tile_cache_init (void)
 {
-  g_signal_connect (gegl_config (), "notify::tile-cache-size",
-                    G_CALLBACK (gegl_config_tile_cache_size_notify), NULL);
+  g_signal_connect (gegl_buffer_config (), "notify::tile-cache-size",
+                    G_CALLBACK (gegl_buffer_config_tile_cache_size_notify), NULL);
 }
 
 void
 gegl_tile_cache_destroy (void)
 {
-  g_signal_handlers_disconnect_by_func (gegl_config(),
-                                        gegl_config_tile_cache_size_notify,
+  g_signal_handlers_disconnect_by_func (gegl_buffer_config(),
+                                        gegl_buffer_config_tile_cache_size_notify,
                                         NULL);
 
   g_warn_if_fail (g_queue_is_empty (&cache_queue));
