@@ -23,12 +23,12 @@
 
 #include <glib-object.h>
 
+#include "gegl-buffer.h"
 #include "gegl-buffer-types.h"
 #include "gegl-tile-handler-cache.h"
 #include "gegl-tile-handler-private.h"
 #include "gegl-tile-storage.h"
 #include "gegl-buffer-private.h"
-#include "gegl-config.h"
 
 struct _GeglTileHandlerPrivate
 {
@@ -36,7 +36,8 @@ struct _GeglTileHandlerPrivate
   GeglTileHandlerCache *cache;
 };
 
-G_DEFINE_TYPE (GeglTileHandler, gegl_tile_handler, GEGL_TYPE_TILE_SOURCE)
+G_DEFINE_TYPE_WITH_PRIVATE (GeglTileHandler, gegl_tile_handler,
+                            GEGL_TYPE_TILE_SOURCE)
 
 enum
 {
@@ -129,8 +130,6 @@ gegl_tile_handler_class_init (GeglTileHandlerClass *klass)
                                                         G_TYPE_OBJECT,
                                                         G_PARAM_READWRITE |
                                                         G_PARAM_CONSTRUCT));
-
-  g_type_class_add_private (gobject_class, sizeof (GeglTileHandlerPrivate));
 }
 
 static void
@@ -138,9 +137,7 @@ gegl_tile_handler_init (GeglTileHandler *self)
 {
   ((GeglTileSource *) self)->command = gegl_tile_handler_command;
 
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-                                            GEGL_TYPE_TILE_HANDLER,
-                                            GeglTileHandlerPrivate);
+  self->priv = gegl_tile_handler_get_instance_private (self);
 }
 
 void
@@ -251,8 +248,7 @@ gegl_tile_handler_damage_rect (GeglTileHandler     *handler,
 
   source = GEGL_TILE_SOURCE (handler);
 
-  if (gegl_config_threads()>1)
-    g_rec_mutex_lock (&handler->priv->tile_storage->mutex);
+  g_rec_mutex_lock (&handler->priv->tile_storage->mutex);
 
   tile_width  = handler->priv->tile_storage->tile_width;
   tile_height = handler->priv->tile_storage->tile_height;
@@ -340,6 +336,5 @@ gegl_tile_handler_damage_rect (GeglTileHandler     *handler,
         }
     }
 
-  if (gegl_config_threads()>1)
-    g_rec_mutex_unlock (&handler->priv->tile_storage->mutex);
+  g_rec_mutex_unlock (&handler->priv->tile_storage->mutex);
 }
