@@ -17,7 +17,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * 2006-2008 © Øyvind Kolås.
  */
@@ -277,7 +277,7 @@ gegl_module_register (GTypeModule *module)
 #define property_pointer(name, label, def_val)    ITEM(name,label,def_val,pointer)
 #define property_object(name, label, def_val)     ITEM2(name,label,def_val,object)
 #define property_enum(name, label, enm, enum_name, def_val)  ITEM(name,label,def_val,pointer)
-#define property_seed(name, label, rand_name)     ITEM(name,label,def_val,int)
+#define property_seed(name, label, rand_name)     ITEM(name,label,def_val,uint)
 #define property_format(name, label, def_val)     ITEM(name,label,def_val,pointer)
 #define property_curve(name, label, def_val)      ITEM2(name,label,def_val,object)
 #define property_path(name, label, def_val)       ITEM2(name,label,def_val,object)
@@ -286,12 +286,14 @@ gegl_module_register (GTypeModule *module)
 
 #define enum_start(enum_name)   typedef enum {
 #define enum_value(value, nick, name)    value ,
+#define enum_value_skip(value)           value ,
 #define enum_end(enum)          } enum ;
 
 #include GEGL_OP_C_FILE
 
 #undef enum_start
 #undef enum_value
+#undef enum_value_skip
 #undef enum_end
 
 #ifdef GETTEXT_PACKAGE
@@ -311,6 +313,8 @@ static GType enum_name ## _get_type (void)               \
 #define enum_value(value, nick, name)                \
       { value, name, nick },
 
+#define enum_value_skip(value)
+
 #define enum_end(enum)                                            \
       { 0, NULL, NULL }                                           \
     };                                                            \
@@ -346,9 +350,11 @@ static GType enum_name ## _get_type (void)               \
 #undef property_path
 #undef enum_start
 #undef enum_value
+#undef enum_value_skip
 #undef enum_end
 #define enum_start(enum_name)
 #define enum_value(value, nick, name)
+#define enum_value_skip(value)
 #define enum_end(enum)
 
 /* Properties */
@@ -370,7 +376,7 @@ struct _GeglProperties
 #define property_pointer(name, label, def_val)         gpointer    name;
 #define property_format(name, label, def_val)          gpointer    name;
 #define property_enum(name, label, enum, enum_name, def_val) enum        name;
-#define property_seed(name, label, rand_name)          gint        name;\
+#define property_seed(name, label, rand_name)          guint       name;\
                                                        GeglRandom *rand_name;
 
 #include GEGL_OP_C_FILE
@@ -416,7 +422,7 @@ enum
 #define property_pointer(name, label, def_val)    ITEM(name,label,def_val,pointer)
 #define property_format(name, label, def_val)     ITEM(name,label,def_val,pointer)
 #define property_enum(name, label, enm, enum_name, def_val) ITEM(name,label,def_val,enum)
-#define property_seed(name, label, rand_name)     ITEM(name,label,def_val,int)
+#define property_seed(name, label, rand_name)     ITEM(name,label,def_val,uint)
 
 #include GEGL_OP_C_FILE
 
@@ -558,7 +564,7 @@ set_property (GObject      *gobject,
       break;
 #define property_seed(name, label, rand_name)                         \
     case PROP_##name:                                                 \
-      properties->name = g_value_get_int (value);                     \
+      properties->name = g_value_get_uint (value);                     \
       if (!properties->rand_name)                                     \
         properties->rand_name = gegl_random_new_with_seed (properties->name);\
       else                                                            \
