@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2003 Calvin Williamson
  *           2006-2008 Øyvind Kolås
@@ -31,6 +31,7 @@
 #include "gegl-operation-context-private.h"
 #include "gegl-node-private.h"
 #include "gegl-buffer-private.h"
+#include "gegl-tile-backend-buffer.h"
 #include "gegl-config.h"
 
 #include "operation/gegl-operation.h"
@@ -199,10 +200,12 @@ gegl_operation_context_add_value (GeglOperationContext *self,
 }
 
 GeglOperationContext *
-gegl_operation_context_new (GeglOperation *operation)
+gegl_operation_context_new (GeglOperation *operation,
+                            GHashTable    *hashtable)
 {
   GeglOperationContext *self = g_slice_new0 (GeglOperationContext);
   self->operation = operation;
+  self->contexts = hashtable;
   return self;
 }
 
@@ -400,32 +403,30 @@ gegl_operation_context_get_output_maybe_in_place (GeglOperation *operation,
   return output;
 }
 
+GeglOperationContext *
+gegl_operation_context_node_get_context (GeglOperationContext *context,
+                                         GeglNode             *node)
+{
+  if (context->contexts)
+    return g_hash_table_lookup (context->contexts, node);
+  return NULL;
+}
+
+
 GeglBuffer *
 gegl_operation_context_dup_input_maybe_copy (GeglOperationContext *context,
                                              const gchar          *padname,
                                              const GeglRectangle  *roi)
 {
-  GeglBuffer    *input;
-  GeglBuffer    *output;
-  GeglBuffer    *result;
-  GeglRectangle  required;
-  GeglRectangle  temp;
-  gint           shift_x;
-  gint           shift_y;
-  gint           tile_width;
-  gint           tile_height;
+  GeglBuffer *input;
+  GeglBuffer *output;
+  GeglBuffer *result;
 
   input = GEGL_BUFFER (gegl_operation_context_get_object (context, padname));
 
   if (! input)
     return NULL;
 
-  /* return input directly when processing a level greater than 0, since
-   * gegl_buffer_copy() only copies level-0 tiles
-   */
-  if (context->level > 0)
-    return g_object_ref (input);
-
   output = GEGL_BUFFER (gegl_operation_context_get_object (context, "output"));
 
   /* return input directly when processing in-place, otherwise, the copied
@@ -434,63 +435,107 @@ gegl_operation_context_dup_input_maybe_copy (GeglOperationContext *context,
   if (input == output)
     return g_object_ref (input);
 
-  /* get required region to copy */
-  required = gegl_operation_get_required_for_output (context->operation,
-                                                     padname, roi);
+#if 1
+  {
+    GeglTileBackend *backend;
 
-  /* return input directly if the required rectangle is infinite, so that we
-   * don't attempt to copy an infinite region
-   */
-  if (gegl_rectangle_is_infinite_plane (&required))
-    return g_object_ref (input);
+    backend = gegl_tile_backend_buffer_new (input);
+    gegl_tile_backend_set_flush_on_destroy (backend, FALSE);
 
-  /* align required region to the tile grid */
-  shift_x     = input->shift_x;
-  shift_y     = input->shift_y;
-  tile_width  = input->tile_width;
-  tile_height = input->tile_height;
+    /* create new buffer with similar characteristics to the input buffer */
+    result = g_object_new (GEGL_TYPE_BUFFER,
+                           "format",       input->soft_format,
+                           "x",            input->extent.x,
+                           "y",            input->extent.y,
+                           "width",        input->extent.width,
+                           "height",       input->extent.height,
+                           "abyss-x",      input->abyss.x,
+                           "abyss-y",      input->abyss.y,
+                           "abyss-width",  input->abyss.width,
+                           "abyss-height", input->abyss.height,
+                           "shift-x",      input->shift_x,
+                           "shift-y",      input->shift_y,
+                           "tile-width",   input->tile_width,
+                           "tile-height",  input->tile_height,
+                           "backend",      backend,
+                           NULL);
 
-  temp.x      = (gint) floor ((gdouble) (required.x                   + shift_x) / tile_width)  * tile_width;
-  temp.y      = (gint) floor ((gdouble) (required.y                   + shift_y) / tile_height) * tile_height;
-  temp.width  = (gint) ceil  ((gdouble) (required.x + required.width  + shift_x) / tile_width)  * tile_width  - temp.x;
-  temp.height = (gint) ceil  ((gdouble) (required.y + required.height + shift_y) / tile_height) * tile_height - temp.y;
-
-  temp.x -= shift_x;
-  temp.y -= shift_y;
-
-  required = temp;
-
-  /* intersect required region with input abyss */
-  gegl_rectangle_intersect (&required, &required, &input->abyss);
-
-  /* create new buffer with similar characteristics to the input buffer */
-  result = g_object_new (GEGL_TYPE_BUFFER,
-                         "format",       input->soft_format,
-                         "x",            input->extent.x,
-                         "y",            input->extent.y,
-                         "width",        input->extent.width,
-                         "height",       input->extent.height,
-                         "abyss-x",      input->abyss.x,
-                         "abyss-y",      input->abyss.y,
-                         "abyss-width",  input->abyss.width,
-                         "abyss-height", input->abyss.height,
-                         "shift-x",      shift_x,
-                         "shift-y",      shift_y,
-                         "tile-width",   tile_width,
-                         "tile-height",  tile_height,
-                         NULL);
-
-  /* if the tile size doesn't match, bail */
-  if (result->tile_width != tile_width || result->tile_height != tile_height)
-    {
-      g_object_unref (result);
+    g_object_unref (backend);
+  }
+#else
+  {
+    GeglRectangle required;
+    GeglRectangle temp;
+    gint          shift_x;
+    gint          shift_y;
+    gint          tile_width;
+    gint          tile_height;
 
+    /* return input directly when processing a level greater than 0, since
+     * gegl_buffer_copy() only copies level-0 tiles
+     */
+    if (context->level > 0)
       return g_object_ref (input);
-    }
 
-  /* copy required region from input to result -- tiles will generally be COWed */
-  gegl_buffer_copy (input,  &required, GEGL_ABYSS_NONE,
-                    result, &required);
+    /* get required region to copy */
+    required = gegl_operation_get_required_for_output (context->operation,
+                                                       padname, roi);
+
+    /* return input directly if the required rectangle is infinite, so that we
+     * don't attempt to copy an infinite region
+     */
+    if (gegl_rectangle_is_infinite_plane (&required))
+      return g_object_ref (input);
+
+    /* align required region to the tile grid */
+    shift_x     = input->shift_x;
+    shift_y     = input->shift_y;
+    tile_width  = input->tile_width;
+    tile_height = input->tile_height;
+
+    temp.x      = (gint) floor ((gdouble) (required.x                   + shift_x) / tile_width)  * tile_width;
+    temp.y      = (gint) floor ((gdouble) (required.y                   + shift_y) / tile_height) * tile_height;
+    temp.width  = (gint) ceil  ((gdouble) (required.x + required.width  + shift_x) / tile_width)  * tile_width  - temp.x;
+    temp.height = (gint) ceil  ((gdouble) (required.y + required.height + shift_y) / tile_height) * tile_height - temp.y;
+
+    temp.x -= shift_x;
+    temp.y -= shift_y;
+
+    required = temp;
+
+    /* intersect required region with input abyss */
+    gegl_rectangle_intersect (&required, &required, &input->abyss);
+
+    /* create new buffer with similar characteristics to the input buffer */
+    result = g_object_new (GEGL_TYPE_BUFFER,
+                           "format",       input->soft_format,
+                           "x",            input->extent.x,
+                           "y",            input->extent.y,
+                           "width",        input->extent.width,
+                           "height",       input->extent.height,
+                           "abyss-x",      input->abyss.x,
+                           "abyss-y",      input->abyss.y,
+                           "abyss-width",  input->abyss.width,
+                           "abyss-height", input->abyss.height,
+                           "shift-x",      shift_x,
+                           "shift-y",      shift_y,
+                           "tile-width",   tile_width,
+                           "tile-height",  tile_height,
+                           NULL);
+
+    /* if the tile size doesn't match, bail */
+    if (result->tile_width != tile_width || result->tile_height != tile_height)
+      {
+        g_object_unref (result);
+
+        return g_object_ref (input);
+      }
+
+    /* copy required region from input to result -- tiles will generally be COWed */
+    gegl_buffer_copy (input,  &required, GEGL_ABYSS_NONE,
+                      result, &required);
+  }
+#endif
 
   return result;
 }
