@@ -21,6 +21,8 @@
 
 #include <glib-object.h>
 
+#define GEGL_ITERATOR2_API
+
 #include "gegl.h"
 #include "gegl-debug.h"
 #include "gegl-operation-point-composer.h"
@@ -64,7 +66,8 @@ static void thread_process (gpointer thread_data, gpointer unused)
                                                     data->level,
                                                     data->output_format,
                                                     GEGL_ACCESS_WRITE,
-                                                    GEGL_ABYSS_NONE);
+                                                    GEGL_ABYSS_NONE,
+                                                    4);
 
   if (data->input)
     read = gegl_buffer_iterator_add (i, data->input, &data->result, data->level,
@@ -78,9 +81,9 @@ static void thread_process (gpointer thread_data, gpointer unused)
   while (gegl_buffer_iterator_next (i))
   {
      data->success =
-     data->klass->process (data->operation, data->input?i->data[read]:NULL,
-                           data->aux?i->data[aux]:NULL,
-                           i->data[0], i->length, &(i->roi[0]), data->level);
+     data->klass->process (data->operation, data->input?i->items[read].data:NULL,
+                           data->aux?i->items[aux].data:NULL,
+                           i->items[0].data, i->length, &(i->items[0].roi), data->level);
   }
 
   g_atomic_int_add (data->pending, -1);
@@ -370,9 +373,9 @@ gegl_operation_point_composer_process (GeglOperation       *operation,
         if (gegl_cl_is_accelerated ())
         {
           if (input)
-            gegl_buffer_cl_cache_flush (input, result);
+            gegl_buffer_flush_ext (input, result);
           if (aux)
-            gegl_buffer_cl_cache_flush (aux, result);
+            gegl_buffer_flush_ext (aux, result);
         }
 
         for (gint j = 1; j < threads; j++)
@@ -385,7 +388,7 @@ gegl_operation_point_composer_process (GeglOperation       *operation,
       }
       else
       {
-        GeglBufferIterator *i = gegl_buffer_iterator_new (output, result, level, out_format, GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE);
+        GeglBufferIterator *i = gegl_buffer_iterator_new (output, result, level, out_format, GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE, 4);
         gint foo = 0, read = 0;
 
         if (input)
@@ -395,9 +398,9 @@ gegl_operation_point_composer_process (GeglOperation       *operation,
 
         while (gegl_buffer_iterator_next (i))
           {
-            point_composer_class->process (operation, input?i->data[read]:NULL,
-                                                      aux?i->data[foo]:NULL,
-                                                      i->data[0], i->length, &(i->roi[0]), level);
+            point_composer_class->process (operation, input?i->items[read].data:NULL,
+                                                      aux?i->items[foo].data:NULL,
+                                                      i->items[0].data, i->length, &(i->items[0].roi), level);
           }
         return TRUE;
       }
