@@ -21,6 +21,7 @@
 
 #include <glib-object.h>
 
+#define GEGL_ITERATOR2_API
 #include "gegl.h"
 #include "gegl-operation-point-render.h"
 #include "gegl-operation-context.h"
@@ -100,10 +101,10 @@ gegl_operation_point_render_process (GeglOperation       *operation,
   if ((result->width > 0) && (result->height > 0))
     {
       GeglBufferIterator *i = gegl_buffer_iterator_new (output, result, level, out_format,
-                                                        GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE);
+                                                        GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE, 2);
 
       while (gegl_buffer_iterator_next (i))
-          point_render_class->process (operation, i->data[0], i->length, &i->roi[0], level);
+          point_render_class->process (operation, i->items[0].data, i->length, &i->items[0].roi, level);
     }
 
   return TRUE;
