@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2013 Daniel Sabo
  *           2006 Øyvind Kolås
@@ -26,7 +26,7 @@
 #include "gegl-debug.h"
 #include "gegl-instrument.h"
 
-#include "buffer/gegl-region.h"
+#include "gegl-region.h"
 
 #include "graph/gegl-node-private.h"
 #include "graph/gegl-pad.h"
@@ -208,7 +208,8 @@ gegl_graph_prepare (GeglGraphTraversal *path)
 
     if (!g_hash_table_contains (path->contexts, node))
       {
-        GeglOperationContext *context = gegl_operation_context_new (node->operation);
+        GeglOperationContext *context = gegl_operation_context_new (node->operation,
+                                           path->contexts);
 
         g_hash_table_insert (path->contexts,
                              node,
