@@ -20,6 +20,7 @@
  * Copyright 1997 Brian Degenhardt <bdegenha@ucsd.edu>
  */
 
+#define GEGL_ITERATOR2_API
 #include "config.h"
 #include <glib/gi18n-lib.h>
 
@@ -45,6 +46,7 @@ property_double (phi, _("Phase shift"), 0.0)
 property_double (angle, _("Angle"), 0.0)
     value_range (-180, 180)
     ui_meta     ("unit", "degree")
+    ui_meta     ("direction", "ccw")
 
 property_enum  (sampler_type, _("Resampling method"),
     GeglSamplerType, gegl_sampler_type, GEGL_SAMPLER_CUBIC)
@@ -179,16 +181,16 @@ process (GeglOperation       *operation,
     }
 
   iter = gegl_buffer_iterator_new (output, result, 0, format,
-                                   GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE);
+                                   GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE, 1);
 
   while (gegl_buffer_iterator_next (iter))
     {
       gint x = result->x;
       gint y = result->y;
-      gfloat *out_pixel = iter->data[0];
+      gfloat *out_pixel = iter->items[0].data;
 
-      for (y = iter->roi[0].y; y < iter->roi[0].y + iter->roi[0].height; ++y)
-        for (x = iter->roi[0].x; x < iter->roi[0].x + iter->roi[0].width; ++x)
+      for (y = iter->items[0].roi.y; y < iter->items[0].roi.y + iter->items[0].roi.height; ++y)
+        for (x = iter->items[0].roi.x; x < iter->items[0].roi.x + iter->items[0].roi.width; ++x)
           {
             gdouble shift;
             gdouble coordsx;
@@ -259,7 +261,7 @@ gegl_op_class_init (GeglOpClass *klass)
     "categories",         "distort",
     "position-dependent", "true",
     "license",            "GPL3+",
-    "reference-hash",     "7aa0097faf41522087353718516b8e15",
+    "reference-hash",     "7f291e2dfcc59d6832be21c839e58963",
     "description", _("Displace pixels in a ripple pattern"),
     NULL);
 }
