@@ -11,12 +11,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * Tile paper ported to GEGL:
  * Copyright 2015 Akash Hiremath (akash akya) <akashh246@gmail.com>
  */
 
+#define GEGL_ITERATOR2_API
 #include "config.h"
 #include <glib/gi18n-lib.h>
 
@@ -125,13 +126,6 @@ random_move (gint             tile_x,
   *y = (gint) (radius * sin (angle));
 }
 
-static void
-prepare (GeglOperation *operation)
-{
-  gegl_operation_set_format (operation, "input",  babl_format ("RGBA float"));
-  gegl_operation_set_format (operation, "output", babl_format ("RGBA float"));
-}
-
 static void
 randomize_tiles (GeglProperties      *o,
                  const GeglRectangle *rect,
@@ -314,14 +308,14 @@ set_background (GeglProperties      *o,
         }
 
       iter = gegl_buffer_iterator_new (input, &clear, 0, format,
-                                       GEGL_ACCESS_READ, GEGL_ABYSS_NONE);
+                                       GEGL_ACCESS_READ, GEGL_ABYSS_NONE, 2);
       gegl_buffer_iterator_add (iter, output, &clear, 0, format,
                                 GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE);
 
       while (gegl_buffer_iterator_next (iter))
         {
-          gfloat  *src      = iter->data[0];
-          gfloat  *dst      = iter->data[1];
+          gfloat  *src      = iter->items[0].data;
+          gfloat  *dst      = iter->items[1].data;
           glong    n_pixels = iter->length;
 
           while (n_pixels--)
@@ -426,7 +420,6 @@ gegl_op_class_init (GeglOpClass *klass)
   filter_class    = GEGL_OPERATION_FILTER_CLASS (klass);
 
   operation_class->threaded                = FALSE;
-  operation_class->prepare                 = prepare;
   operation_class->get_required_for_output = get_required_for_output;
   operation_class->get_cached_region       = get_cached_region;
 
