@@ -11,12 +11,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2011 Audrey Mandet <mandet.audrey@gmail.com>
  * Copyright (c) 1997 Eric L. Hernes (erich@rrnet.com), Stephen Norris
  */
 
+#define GEGL_ITERATOR2_API
 #include "config.h"
 #include <glib/gi18n-lib.h>
 #include <math.h>
@@ -69,14 +70,24 @@ prepare (GeglOperation *operation)
 {
   GeglOperationAreaFilter *op_area = GEGL_OPERATION_AREA_FILTER (operation);
   GeglProperties          *o       = GEGL_PROPERTIES (operation);
+  const Babl              *space   = gegl_operation_get_source_space (operation, "input");
 
   op_area->left   = o->amplitude;
   op_area->right  = o->amplitude;
   op_area->top    = o->amplitude;
   op_area->bottom = o->amplitude;
 
-  gegl_operation_set_format (operation, "input",  babl_format ("RGBA float"));
-  gegl_operation_set_format (operation, "output", babl_format ("RGBA float"));
+  gegl_operation_set_format (operation, "input",  babl_format_with_space ("RGBA float", space));
+  gegl_operation_set_format (operation, "output", babl_format_with_space ("RGBA float", space));
+}
+
+static GeglAbyssPolicy
+get_abyss_policy (GeglOperation *operation,
+                  const gchar   *input_pad)
+{
+  GeglProperties *o = GEGL_PROPERTIES (operation);
+
+  return o->clamp ? GEGL_ABYSS_CLAMP : GEGL_ABYSS_NONE;
 }
 
 static gboolean
@@ -87,14 +98,14 @@ process (GeglOperation       *operation,
          gint                 level)
 {
   GeglProperties     *o       = GEGL_PROPERTIES (operation);
-  GeglSampler        *sampler = gegl_buffer_sampler_new_at_level (input,
-                                                         babl_format ("RGBA float"),
+  const Babl         *format  = gegl_operation_get_format (operation, "output");
+  GeglSampler        *sampler = gegl_buffer_sampler_new_at_level (input, format,
                                                          o->sampler_type,
                                                          level);
   GeglRectangle      *in_extent = gegl_operation_source_get_bounding_box (operation, "input");
   GeglBufferIterator *iter;
 
-  GeglAbyssPolicy abyss = o->clamp ? GEGL_ABYSS_CLAMP : GEGL_ABYSS_NONE;
+  GeglAbyssPolicy abyss = get_abyss_policy (operation, "input");
 
   gdouble px_x = gegl_coordinate_relative_to_pixel (o->x, in_extent->width);
   gdouble px_y = gegl_coordinate_relative_to_pixel (o->y, in_extent->height);
@@ -118,17 +129,17 @@ process (GeglOperation       *operation,
       scaley = 1.0;
     }
 
-  iter = gegl_buffer_iterator_new (output, result, 0, babl_format ("RGBA float"),
-                                   GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE);
+  iter = gegl_buffer_iterator_new (output, result, 0, format,
+                                   GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE, 1);
 
   while (gegl_buffer_iterator_next (iter))
     {
       gint x = result->x;
       gint y = result->y;
-      gfloat *out_pixel = iter->data[0];
+      gfloat *out_pixel = iter->items[0].data;
 
-      for (y = iter->roi[0].y; y < iter->roi[0].y + iter->roi[0].height; ++y)
-        for (x = iter->roi[0].x; x < iter->roi[0].x + iter->roi[0].width; ++x)
+      for (y = iter->items[0].roi.y; y < iter->items[0].roi.y + iter->items[0].roi.height; ++y)
+        for (x = iter->items[0].roi.x; x < iter->items[0].roi.x + iter->items[0].roi.width; ++x)
           {
             gdouble radius;
             gdouble shift;
@@ -170,21 +181,24 @@ process (GeglOperation       *operation,
 static void
 gegl_op_class_init (GeglOpClass *klass)
 {
-  GeglOperationClass       *operation_class;
-  GeglOperationFilterClass *filter_class;
+  GeglOperationClass           *operation_class;
+  GeglOperationFilterClass     *filter_class;
+  GeglOperationAreaFilterClass *area_class;
 
   operation_class = GEGL_OPERATION_CLASS (klass);
   filter_class    = GEGL_OPERATION_FILTER_CLASS (klass);
+  area_class      = GEGL_OPERATION_AREA_FILTER_CLASS (klass);
 
-  operation_class->prepare = prepare;
-  filter_class->process    = process;
+  operation_class->prepare     = prepare;
+  filter_class->process        = process;
+  area_class->get_abyss_policy = get_abyss_policy;
 
   gegl_operation_class_set_keys (operation_class,
     "name",               "gegl:waves",
     "title",              _("Waves"),
     "categories",         "distort",
     "position-dependent", "true",
-    "reference-hash",     "8db35f18f7991b9f6c56f6ca25188fd6",
+    "reference-hash",     "5c9428be7c567630854d681617bc245f",
     "license",            "GPL3+",
     "description", _("Distort the image with waves"),
     NULL);
