@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2006 Øyvind Kolås <pippin@gimp.org>
  */
@@ -35,22 +35,17 @@
 
 static void prepare (GeglOperation *operation)
 {
+  const Babl *space = gegl_operation_get_source_space (operation, "input");
   const Babl *format;
   const Babl *input_format;
 
   input_format = gegl_operation_get_source_format (operation, "input");
-  if (input_format == NULL)
-    {
-      format = babl_format ("YA float");
-      goto out;
-    }
 
-  if (babl_format_has_alpha (input_format))
-    format = babl_format ("YA float");
+  if (input_format && babl_format_has_alpha (input_format))
+    format = babl_format_with_space ("YA float", space);
   else
-    format = babl_format ("Y float");
+    format = babl_format_with_space ("Y float", space);
 
- out:
   gegl_operation_set_format (operation, "input", format);
   gegl_operation_set_format (operation, "output", format);
 }
