@@ -11,13 +11,14 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2007,2009,2018 Øyvind Kolås     <pippin@gimp.org>
  *           2007           Ivar Farup       <ivarf@hig.no>
  *           2007           Allesandro Rizzi <rizzi@dti.unimi.it>
  */
 
+#define GEGL_ITERATOR2_API
 #include "config.h"
 #include <glib/gi18n-lib.h>
 
@@ -77,14 +78,15 @@ static void stress (GeglBuffer          *src,
                     gint                 iterations,
                     gdouble              rgamma,
                     gboolean             enhance_shadows,
-                    gint                 level)
+                    gint                 level,
+                    const Babl          *space)
 {
-  const Babl *format = babl_format ("RGBA float");
+  const Babl *format = babl_format_with_space ("RGBA float", space);
 
   if (dst_rect->width > 0 && dst_rect->height > 0)
   {
-    GeglBufferIterator *i = gegl_buffer_iterator_new (dst, dst_rect, 0, babl_format("RaGaBaA float"),
-                                                      GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE);
+    GeglBufferIterator *i = gegl_buffer_iterator_new (dst, dst_rect, 0, babl_format_with_space ("RaGaBaA float", space),
+                                                      GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE, 1);
     GeglSampler *sampler = gegl_buffer_sampler_new_at_level (src, format, GEGL_SAMPLER_NEAREST, level);
     GeglSamplerGetFun getfun = gegl_sampler_get_fun (sampler);
 
@@ -92,12 +94,13 @@ static void stress (GeglBuffer          *src,
     {
       gint x,y;
       gint    dst_offset=0;
-      gfloat *dst_buf = i->data[0];
+      gfloat *dst_buf = i->items[0].data;
+      GeglRectangle *roi = &i->items[0].roi;
 
       if (enhance_shadows)
       {
-        for (y=i->roi[0].y; y < i->roi[0].y + i->roi[0].height; y++)
-          for (x=i->roi[0].x; x < i->roi[0].x + i->roi[0].width; x++)
+        for (y=roi->y; y < roi->y + roi->height; y++)
+          for (x=roi->x; x < roi->x + roi->width; x++)
             {
               gfloat  min[4];
               gfloat  max[4];
@@ -138,8 +141,8 @@ static void stress (GeglBuffer          *src,
       }
       else
       {
-        for (y=i->roi[0].y; y < i->roi[0].y + i->roi[0].height; y++)
-          for (x=i->roi[0].x; x < i->roi[0].x + i->roi[0].width; x++)
+        for (y=roi->y; y < roi->y + roi->height; y++)
+          for (x=roi->x; x < roi->x + roi->width; x++)
             {
               gfloat  max[4];
               gfloat  pixel[4];
@@ -183,12 +186,13 @@ static void stress (GeglBuffer          *src,
 
 static void prepare (GeglOperation *operation)
 {
+  const Babl *space = gegl_operation_get_source_space (operation, "input");
   GeglOperationAreaFilter *area = GEGL_OPERATION_AREA_FILTER (operation);
   area->left = area->right = area->top = area->bottom =
       ceil (GEGL_PROPERTIES (operation)->radius);
 
   gegl_operation_set_format (operation, "output",
-                             babl_format ("RaGaBaA float"));
+                             babl_format_with_space ("RaGaBaA float", space));
 }
 
 static GeglRectangle
@@ -210,6 +214,7 @@ process (GeglOperation       *operation,
          gint                 level)
 {
   GeglProperties *o = GEGL_PROPERTIES (operation);
+  const Babl *space = babl_format_get_space (gegl_operation_get_format (operation, "output"));
   GeglRectangle compute;
   compute = gegl_operation_get_required_for_output (operation, "input",result);
 
@@ -219,7 +224,8 @@ process (GeglOperation       *operation,
           o->iterations,
           RGAMMA /*o->rgamma,*/,
           o->enhance_shadows,
-          level);
+          level,
+          space);
 
   return  TRUE;
 }
