@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2006 Øyvind Kolås <pippin@gimp.org>
  */
@@ -37,9 +37,10 @@ property_double (value, _("Threshold"), 0.5)
 
 static void prepare (GeglOperation *operation)
 {
-  gegl_operation_set_format (operation, "input",  babl_format ("YA float"));
-  gegl_operation_set_format (operation, "aux",    babl_format ("Y float"));
-  gegl_operation_set_format (operation, "output", babl_format ("YA float"));
+  const Babl *space = gegl_operation_get_source_space (operation, "input");
+  gegl_operation_set_format (operation, "input",  babl_format_with_space ("Y'A float", space));
+  gegl_operation_set_format (operation, "aux",    babl_format_with_space ("Y' float", space));
+  gegl_operation_set_format (operation, "output", babl_format_with_space ("Y'A float", space));
 }
 
 static gboolean
