@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2006 Øyvind Kolås <pippin@gimp.org>
  *           2006 Dominik Ernst <dernst@gmx.de>
@@ -90,6 +90,8 @@ export_png (GeglOperation       *operation,
   png_color_16   white;
   int            png_color_type;
   gchar          format_string[16];
+  const Babl    *babl = gegl_buffer_get_format (input);
+  const Babl    *space = babl_format_get_space (babl);
   const Babl    *format;
 
   src_x = result->x;
@@ -98,7 +100,6 @@ export_png (GeglOperation       *operation,
   height = result->height;
 
   {
-    const Babl *babl = gegl_buffer_get_format (input);
 
     if (bit_depth != 16)
       bit_depth = 8;
@@ -141,25 +142,78 @@ export_png (GeglOperation       *operation,
      width, height, bit_depth, png_color_type,
      PNG_INTERLACE_NONE, PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_DEFAULT);
 
-  if (png_color_type == PNG_COLOR_TYPE_RGB || png_color_type == PNG_COLOR_TYPE_RGB_ALPHA)
+  if (
+      (png_color_type == PNG_COLOR_TYPE_RGB || png_color_type == PNG_COLOR_TYPE_RGB_ALPHA))
     {
-      white.red = 0xff;
-      white.blue = 0xff;
-      white.green = 0xff;
-      png_set_sRGB_gAMA_and_cHRM (png, info, PNG_sRGB_INTENT_RELATIVE);
+      if (space == NULL || space == babl_space ("sRGB"))
+      {
+        white.red = 0xff;
+        white.blue = 0xff;
+        white.green = 0xff;
+        png_set_sRGB_gAMA_and_cHRM (png, info, PNG_sRGB_INTENT_RELATIVE);
+      }
+      else
+      {
+
+        double wp[2];
+        double red[2];
+        double green[2];
+        double blue[2];
+        const Babl *trc[3];
+        babl_space_get (space, &wp[0], &wp[1],
+                        &red[0], &red[1],
+                        &green[0], &green[1],
+                        &blue[0], &blue[1],
+                        &trc[0], &trc[1], &trc[2]);
+        png_set_cHRM (png, info, wp[0], wp[1], red[0], red[1], green[0], green[1], blue[0], blue[1]);
+      /* XXX: should also set gamma based on trc! */
+        if (trc[0] == babl_trc("sRGB") ||
+            trc[0] == babl_trc("2.2"))
+        {
+          png_set_gAMA (png, info, 2.2);
+        }
+        else if (trc[0] == babl_trc("linear"))
+        {
+          png_set_gAMA (png, info, 1.0);
+        }
+        else
+        {
+          png_set_gAMA (png, info, 2.2);
+        }
+
+        {
+          int icc_len;
+          const char *name = babl_get_name (space);
+          const char *icc_profile;
+          if (strlen (name) > 10) name = "GEGL";
+          icc_profile = babl_space_get_icc (space, &icc_len);
+          if (icc_profile)
+          {
+             png_set_iCCP (png, info,
+                           name, 0, (void*)icc_profile, icc_len);
+          }
+        }
+      }
     }
   else
-    white.gray = 0xff;
+    {
+      white.gray = 0xff;
+    }
   png_set_bKGD (png, info, &white);
 
+  format = babl_format_with_space (format_string, space);
+
+
+  if (space && space != babl_space("sRGB"))
+  {
+  }
+
   png_write_info (png, info);
 
 #if BYTE_ORDER == LITTLE_ENDIAN
   if (bit_depth > 8)
     png_set_swap (png);
 #endif
-
-  format = babl_format (format_string);
   pixels = g_malloc0 (width * babl_format_get_bytes_per_pixel (format));
 
   for (i=0; i< height; i++)
@@ -171,7 +225,7 @@ export_png (GeglOperation       *operation,
       rect.width = width;
       rect.height = 1;
 
-      gegl_buffer_get (input, &rect, 1.0, babl_format (format_string), pixels, GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);
+      gegl_buffer_get (input, &rect, 1.0, format, pixels, GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);
 
       png_write_rows (png, &pixels, 1);
     }
