@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2015 Martin Blanchard <tchaik@gmx.com>
  */
@@ -38,6 +38,8 @@ property_int(directory, _("Directory"), 1)
 #define GEGL_OP_NAME     tiff_load
 #define GEGL_OP_C_SOURCE tiff-load.c
 
+#define GEGL_ITERATOR2_API
+
 #include <gegl-op.h>
 #include <gegl-gio-private.h>
 #include <glib/gprintf.h>
@@ -354,6 +356,7 @@ query_tiff(GeglOperation *operation)
   gushort nb_extras, planar_config;
   gboolean fallback_mode = FALSE;
   gchar format_string[32];
+  const Babl *space = NULL;
   guint width, height;
 
   g_return_val_if_fail(p->tiff != NULL, -1);
@@ -495,7 +498,21 @@ query_tiff(GeglOperation *operation)
 
   TIFFGetFieldDefaulted(p->tiff, TIFFTAG_PLANARCONFIG, &planar_config);
 
-  p->format = babl_format(format_string);
+  {
+    uint32  profile_size;
+    guchar *icc_profile;
+
+    /* set the ICC profile - if found in the TIFF */
+    if (TIFFGetField (p->tiff, TIFFTAG_ICCPROFILE, &profile_size, &icc_profile))
+      {
+        const char *error = NULL;
+        space = babl_space_from_icc ((char*)icc_profile, (gint)profile_size,
+                                     BABL_ICC_INTENT_RELATIVE_COLORIMETRIC, &error);
+      }
+
+  }
+
+  p->format = babl_format_with_space (format_string, space);
   if (fallback_mode)
     p->mode = TIFF_LOADING_RGBA;
   else if (planar_config == PLANARCONFIG_CONTIG)
@@ -663,7 +680,7 @@ load_separated(GeglOperation *operation,
               iterator = gegl_buffer_iterator_new(linear, &plane_tile,
                                                   0, NULL,
                                                   GEGL_ACCESS_READ,
-                                                  GEGL_ABYSS_NONE);
+                                                  GEGL_ABYSS_NONE, 2);
 
               gegl_buffer_iterator_add(iterator, output, &output_tile,
                                        0, p->format,
@@ -672,8 +689,8 @@ load_separated(GeglOperation *operation,
 
               while (gegl_buffer_iterator_next(iterator))
                 {
-                  guchar *plane_buffer = iterator->data[0];
-                  guchar *output_buffer = iterator->data[1];
+                  guchar *plane_buffer = iterator->items[0].data;
+                  guchar *output_buffer = iterator->items[1].data;
                   gint nb_pixels = iterator->length;
 
                   output_buffer += offset;
