@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2015 Martin Blanchard <tchaik@gmx.com>
  */
@@ -365,6 +365,7 @@ export_tiff (GeglOperation *operation,
              GeglBuffer *input,
              const GeglRectangle *result)
 {
+  const Babl *space;
   GeglProperties *o = GEGL_PROPERTIES(operation);
   Priv *p = (Priv*) o->user_data;
   gshort color_space, compression = COMPRESSION_NONE;
@@ -387,18 +388,26 @@ export_tiff (GeglOperation *operation,
   TIFFSetField(p->tiff, TIFFTAG_IMAGELENGTH, result->height);
 
   format = gegl_buffer_get_format(input);
-
   model = babl_format_get_model(format);
+  space = babl_format_get_space (format);
   type = babl_format_get_type(format, 0);
 
-  if (model == babl_model("Y") || model == babl_model("Y'"))
+  {
+    int icc_len;
+    const char *icc_profile;
+    icc_profile = babl_space_get_icc (space, &icc_len);
+    if (icc_profile)
+      TIFFSetField (p->tiff, TIFFTAG_ICCPROFILE, icc_len, icc_profile);
+  }
+
+  if (babl_model_is (model, "Y") || babl_model_is (model, "Y'"))
     {
       has_alpha = FALSE;
       color_space = PHOTOMETRIC_MINISBLACK;
       model = babl_model("Y'");
       samples_per_pixel = 1;
     }
-  else if (model == babl_model("YA") || model == babl_model("Y'A"))
+  else if (babl_model_is (model, "YA") || babl_model_is (model, "Y'A"))
     {
       has_alpha = TRUE;
       alpha_is_premultiplied = FALSE;
@@ -406,7 +415,7 @@ export_tiff (GeglOperation *operation,
       model = babl_model("Y'A");
       samples_per_pixel = 2;
     }
-  else if (model == babl_model("YaA") || model == babl_model("Y'aA"))
+  else if (babl_model_is (model, "YaA") || babl_model_is (model, "Y'aA"))
     {
       has_alpha = TRUE;
       alpha_is_premultiplied = TRUE;
@@ -414,7 +423,7 @@ export_tiff (GeglOperation *operation,
       model = babl_model("Y'aA");
       samples_per_pixel = 2;
     }
-  else if (model == babl_model("RGB") || model == babl_model("R'G'B'"))
+  else if (babl_model_is (model, "RGB") || babl_model_is (model, "R'G'B'"))
     {
       has_alpha = FALSE;
       color_space = PHOTOMETRIC_RGB;
@@ -422,7 +431,7 @@ export_tiff (GeglOperation *operation,
       samples_per_pixel = 3;
       predictor = 2;
     }
-  else if (model == babl_model("RGBA") || model == babl_model("R'G'B'A"))
+  else if (babl_model_is (model, "RGBA") || babl_model_is (model, "R'G'B'A"))
     {
       has_alpha = TRUE;
       alpha_is_premultiplied = FALSE;
@@ -431,7 +440,7 @@ export_tiff (GeglOperation *operation,
       samples_per_pixel = 4;
       predictor = 2;
     }
-  else if (model == babl_model("RaGaBaA") || model == babl_model("R'aG'aB'aA"))
+  else if (babl_model_is (model, "RaGaBaA") || babl_model_is (model, "R'aG'aB'aA"))
     {
       has_alpha = TRUE;
       alpha_is_premultiplied = TRUE;
@@ -530,7 +539,7 @@ export_tiff (GeglOperation *operation,
   g_snprintf(format_string, 32, "%s %s",
              babl_get_name(model), babl_get_name(type));
 
-  format = babl_format(format_string);
+  format = babl_format_with_space (format_string, space);
 
   /* "Choose RowsPerStrip such that each strip is about 8K bytes." */
   bytes_per_row = babl_format_get_bytes_per_pixel(format) * result->width;
